# remirepo spec file for php-pecl-skywalking-agent
#
# SPDX-FileCopyrightText:  Copyright 2024 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%if 0%{?scl:1}
%scl_package       php-pecl-skywalking-agent
%else
%global _root_bindir %{_bindir}
%endif

# notice: ZTS not supported by upstream
%global pecl_name  skywalking_agent
%global ini_name   40-%{pecl_name}.ini
%global sources    %{pecl_name}-%{version}

## BUILD: Fedora / EL-8 and EL-9 using --enablerepo=stream if needed


Summary:        Apache SkyWalking PHP Agent
Name:           %{?scl_prefix}php-pecl-skywalking-agent
Version:        0.8.0
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        Apache-2.0
URL:            https://pecl.php.net/package/%{pecl_name}

Source0:        https://pecl.php.net/get/%{sources}.tgz
# awfull hack, use a bundled rust registry
Source1:        makedeps.sh
Source2:        %{pecl_name}-deps-%{version}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?dtsprefix}gcc-c++
BuildRequires:  %{?scl_prefix}php-devel >= 7.2
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  cargo >= 1.65
BuildRequires:  rustfmt
BuildRequires:  protobuf-compiler
BuildRequires:  clang-devel
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  openssl-devel
%if 0%{?fedora} >= 41
BuildRequires:  openssl-devel-engine
%endif
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 9
BuildRequires:  rust-packaging
%endif

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
The PHP Agent for Apache SkyWalking, which provides the native tracing
abilities for PHP project.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c -a2

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

# Create cargo configuration to use vendor directory
mkdir .cargo
cat << EOF | tee .cargo/config.toml
[build]
jobs = %(echo %{?_smp_mflags} | sed 's/\-j//')
rustc = "%{_root_bindir}/rustc"

[env]
CFLAGS = "%{build_cflags}"
CXXFLAGS = "%{build_cxxflags}"
LDFLAGS = "%{build_ldflags}"

[term]
verbose = true

[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "$PWD/mycargo"
EOF

pushd %{sources}
: Check version
grep '^version' Cargo.toml
grep '^version = "%{version}"' Cargo.toml
popd

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

; Configuration
;skywalking_agent.enable = 0
;skywalking_agent.skywalking_version = 8
;skywalking_agent.server_addr = 127.0.0.1:11800
;skywalking_agent.instance_name =
;skywalking_agent.service_name = hello-skywalking
;skywalking_agent.worker_threads = 0
;skywalking_agent.log_level = OFF
;skywalking_agent.log_file = /tmp/skywalking-agent.log
;skywalking_agent.runtime_dir = /tmp/skywalking-agent
;skywalking_agent.authentication =
;skywalking_agent.enable_tls = 0
;skywalking_agent.ssl_trusted_ca_path =
;skywalking_agent.ssl_key_path =
;skywalking_agent.ssl_cert_chain_path =
;skywalking_agent.heartbeat_period = 30
;skywalking_agent.properties_report_period_factor = 10
;skywalking_agent.enable_zend_observer = 0
;skywalking_agent.reporter_type = grpc
;skywalking_agent.kafka_bootstrap_servers =
;skywalking_agent.kafka_producer_config = {}
;skywalking_agent.inject_context = 0
;skywalking_agent.standalone_socket_path =
EOF

: Required rust version
grep -h rust-version mycargo/*/Cargo.toml %{sources}/Cargo.toml | sort -u | tail -n 8


%build
%{?dtsenable}

export CARGO_HOME=$PWD/mycargo
export RUSTFLAGS="%{?build_rustflags}%{!?build_rustflags:-Copt-level=3 -Cdebuginfo=2 -Ccodegen-units=1 -Cstrip=none -Cforce-frame-pointers=yes --cap-lints=warn}"

cd %{sources}
%{__phpize}

%configure \
    --enable-skywalking_agent \
%if 0%{?rhel} == 10
    --disable-kafka-reporter \
%else
    --enable-kafka-reporter \
%endif
    --with-php-config=%{__phpconfig}

make %{?_smp_mflags}


%install
%{?dtsenable}

cd %{sources}
make install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 ../%{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 ../package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Documentation
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
# Minimal load test for the extension
%{__php} -n \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'


%files
%license %{sources}/LICENSE %{sources}/dist-material/licenses/LICENSE*
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so


%changelog
* Mon Dec  9 2024 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0
- EL-10 disable kafka reporter - broken build with OPENSSL_NO_ENGINE
  resported as https://github.com/apache/skywalking/issues/12837
- re-license spec file to CECILL-2.1

* Thu Sep 28 2023 Remi Collet <remi@remirepo.net> - 0.7.0-1
- update to 0.7.0

* Fri Aug 25 2023 Remi Collet <remi@remirepo.net> - 0.6.0-1
- update to 0.6.0
- build out of sources tree

* Tue May  9 2023 Remi Collet <remi@remirepo.net> - 0.5.0-1
- update to 0.5.0

* Wed Mar 29 2023 Remi Collet <remi@remirepo.net> - 0.4.0-1
- update to 0.4.0

* Thu Feb  2 2023 Remi Collet <remi@remirepo.net> - 0.3.0-1
- update to 0.3.0

* Mon Nov 28 2022 Remi Collet <remi@remirepo.net> - 0.2.0-1
- update to 0.2.0

* Mon Oct 10 2022 Remi Collet <remi@remirepo.net> - 0.1.0-1
- initial package
- open https://github.com/apache/skywalking/pull/9754   Add PHP component
- open https://github.com/apache/skywalking/issues/9753 Bad role
- open https://github.com/apache/skywalking/issues/9755 8.2 support
- open https://github.com/apache/skywalking/issues/9756 GCC 12 support
- open https://github.com/apache/skywalking/issues/9757 rust 1.58
- open https://github.com/apache/skywalking/issues/9758 offline build
